@@ -69,7 +69,7 @@ QDomDocument CourseParser::loadDomDocument(const QUrl &path, const QXmlSchema &s
     return document;
 }
 
-std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes)
+std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete)
 {
     std::vector<std::unique_ptr<Unit>> units;
 
@@ -96,7 +96,7 @@ std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QV
                 if (xml.name() == "units") {
                     continue;
                 } else if (xml.name() == "unit") {
-                    auto unit = parseUnit(xml, path, phonemes, elementOk);
+                    auto unit = parseUnit(xml, path, phonemes, skipIncomplete, elementOk);
                     if (elementOk) {
                         units.push_back(std::move(unit));
                     }
@@ -115,7 +115,7 @@ std::vector<std::unique_ptr<Unit>> CourseParser::parseUnits(const QUrl &path, QV
     return units;
 }
 
-std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool &ok)
+std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl &path, QVector<std::shared_ptr<Phoneme>> phonemes, bool skipIncomplete, bool &ok)
 {
     std::unique_ptr<Unit> unit(new Unit);
     ok = true;
@@ -144,8 +144,10 @@ std::unique_ptr<Unit> CourseParser::parseUnit(QXmlStreamReader &xml, const QUrl
             }
             else if (xml.name() == "phrase") {
                 auto phrase = parsePhrase(xml, path, phonemes, elementOk);
-                if (elementOk) {
+                if (elementOk && (!skipIncomplete || !phrase->soundFileUrl().isEmpty())) {
                     unit->addPhrase(phrase);
+                } else {
+                    phrase->deleteLater();
                 }
                 ok &= elementOk;
             } else {
@@ -189,9 +191,11 @@ Phrase * CourseParser::parsePhrase(QXmlStreamReader &xml, const QUrl &path, QVec
                 phrase->seti18nText(parseElement(xml, elementOk));
                 ok &= elementOk;
             } else if (xml.name() == "soundFile") {
-                phrase->setSound(QUrl::fromLocalFile(
-                        path.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path()
-                        + '/' + parseElement(xml, elementOk)));
+                QString fileName = parseElement(xml, elementOk);
+                if (!fileName.isEmpty()) {
+                    phrase->setSound(QUrl::fromLocalFile(
+                            path.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path() + '/' + fileName));
+                }
                 ok &= elementOk;
             } else if (xml.name() == "phonemes") {
                 auto parsedPhonemeIds = parsePhonemeIds(xml, elementOk);
@@ -275,7 +279,7 @@ QString CourseParser::parseElement(QXmlStreamReader& xml, bool &ok)
     QString elementName = xml.name().toString();
     xml.readNext();
 
-    qCDebug(ARTIKULATE_PARSER()) << "parsed: " << elementName << " / " << xml.text().toString();
+    //qCDebug(ARTIKULATE_PARSER()) << "parsed: " << elementName << " / " << xml.text().toString();
     return xml.text().toString();
 }
 
