@@ -24,15 +24,14 @@
 #include <QAbstractListModel>
 #include "languagemodel.h"
 
-class ResourceManager;
-class LanguageResource;
-class Language;
+class IResourceRepository;
+class ILanguage;
 class QSignalMapper;
 
 class LanguageResourceModel : public QAbstractListModel
 {
     Q_OBJECT
-    Q_PROPERTY(ResourceManager *resourceManager READ resourceManager WRITE setResourceManager NOTIFY resourceManagerChanged)
+    Q_PROPERTY(IResourceRepository *repository READ resourceRepository WRITE setResourceRepository NOTIFY resourceRepositoryChanged)
 
 public:
     enum LanguageRoles {
@@ -47,33 +46,31 @@ public:
     /**
      * Reimplemented from QAbstractListModel::roleNames()
      */
-    virtual QHash<int,QByteArray> roleNames() const Q_DECL_OVERRIDE;
-    void setResourceManager(ResourceManager *resourceManager);
-    ResourceManager * resourceManager() const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    virtual QHash<int,QByteArray> roleNames() const override;
+    void setResourceRepository(IResourceRepository *repository);
+    IResourceRepository * resourceRepository() const;
+    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
     void setView(LanguageModel::LanguageResourceView view);
     LanguageModel::LanguageResourceView view() const;
 
 Q_SIGNALS:
     void languageChanged(int index);
-    void resourceManagerChanged();
+    void resourceRepositoryChanged();
 
 private Q_SLOTS:
-    void onLanguageResourceAboutToBeAdded(LanguageResource *resource, int index);
-    void onLanguageResourceAdded();
-    void onLanguageResourceAboutToBeRemoved(int index);
-    void onLanguageResourceRemoved();
+    void onLanguageAboutToBeAdded(Language *resource, int index);
+    void onLanguageAdded();
+    void onLanguageAboutToBeRemoved(int index);
+    void onLanguageRemoved();
     void emitLanguageChanged(int row);
     void updateDisplayedLanguages();
 
 private:
-    bool displayResource(LanguageResource *resource) const;
-    void updateResources();
     void updateMappings();
-    ResourceManager *m_resourceManager;
-    QList<LanguageResource *> m_resources;
+    IResourceRepository *m_repository;
+    QVector<ILanguage *> m_languages;
     LanguageModel::LanguageResourceView m_view;
     QSignalMapper *m_signalMapper;
 };
